@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_codecommit._jsii
 import aws_cdk.aws_events._jsii
@@ -15,9 +15,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-pull-request-approval-rule",
-    "1.0.32",
+    "1.0.34",
     __name__[0:-6],
-    "cdk-pull-request-approval-rule@1.0.32.jsii.tgz",
+    "cdk-pull-request-approval-rule@1.0.34.jsii.tgz",
 )
 
 __all__ = [
